import type { ArticleStore } from "../domain/articleStore";
import { useCallback, useEffect } from "react";
import { GetArticleUseCase } from "article/useCases/getArticleUseCase";
import { FetchArticleUseCase } from "article/useCases/fetchArticleUseCase";
import { useParams } from "react-router-dom";

function useArticleViewModel(
  store: ArticleStore,
  fetchArticleUseCase: FetchArticleUseCase,
  getArticleUseCase: GetArticleUseCase,
) {
  const { id } = useParams();

  const getArticle = useCallback(
    (
      articleID: string,
      getArticleUseCase: GetArticleUseCase,
      fetchArticleUseCase: FetchArticleUseCase
    ) => {
      getArticleUseCase.call(articleID).catch((_) => fetchArticleUseCase.call(articleID));
    },
    []
  );

  useEffect(
    () => {
      getArticle(id ?? '', getArticleUseCase, fetchArticleUseCase);
    },
    [
      id,
      getArticle,
      getArticleUseCase,
      fetchArticleUseCase
    ],
  );

  return {
    article: store.currentArticle,
    shouldShowLoading: store.isLoading,
    hasError: store.hasError,
  };
}

export { useArticleViewModel };
